@@ -15,8 +15,8 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with GNU GPERF; see the file COPYING.  If not, write to
-the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
+along with GNU GPERF; see the file COPYING.  If not, write to the Free
+Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111, USA.  */
 
 #include <stdio.h>
 #include <std.h>
@@ -37,7 +37,7 @@ the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
    memory fragmentation, since we can now use alloca! */
  
 Hash_Table::Hash_Table (List_Node **table_ptr, int s): 
-     collisions (0), size (s), table (table_ptr)
+     table (table_ptr), size (s), collisions (0)
 {
   T (Trace t ("Hash_Table::Hash_Table");)
   memset ((char *) table, 0, size * sizeof *table);
